#ifndef REFPOSITION_H
#define REFPOSITION_H

// where a reference must be put

typedef enum {NONE = 0, INLINE = 1, POSTLINE, POSTDOC} RefPosition;

#endif // REFPOSITION_H
